==> SMILA-1.0-core-source.zip: org.eclipse.smila.solr.test/code/src/org/eclipse/smila/solr/AllTests.java <==
// CHECKSTYLE:OFF
/*********************************************************************************************************************
 * Copyright (c) 2008, 2012 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 **********************************************************************************************************************/
package org.eclipse.smila.solr;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 */
public class AllTests {

  public static Test suite() {
    final TestSuite suite = new TestSuite(AllTests.class.getName());
    // $JUnit-BEGIN$
    suite.addTestSuite(SolrSearchPipelet_AddResultRecords_Test.class);
    suite.addTestSuite(ToSolrQueryConverter_Test.class);

    suite.addTestSuite(Facet_Test.class);

    suite.addTestSuite(SolrIndexPipelet_Index_Test.class);
    suite.addTestSuite(SolrIndexPipelet_Delete_Test.class);

    suite.addTestSuite(SolrAdmin_Embedded_Test.class);

    suite.addTestSuite(SolrSearchPipelet_Facet_Test.class);
    suite.addTestSuite(SolrSearchPipelet_HL_Test.class);
    suite.addTestSuite(SolrSearchPipelet_AutoComplete_Test.class);
    suite.addTestSuite(SolrSearchPipelet_DidYouMean_Test.class);

    suite.addTestSuite(SolrSearchPipelet_MoreLikeThis_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Fields_Test.class);

    suite.addTestSuite(SolrSearchPipelet_Filter_OnBounds_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Filter_OnSets_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Sortby_Test.class);

    // $JUnit-END$
    return suite;
  }

}

==> SMILA-1.2-core-source.zip: org.eclipse.smila.solr.test/code/src/org/eclipse/smila/solr/AllTests.java <==
// CHECKSTYLE:OFF
/*********************************************************************************************************************
 * Copyright (c) 2008, 2012 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 **********************************************************************************************************************/
package org.eclipse.smila.solr;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 */
public class AllTests {

  public static Test suite() {
    final TestSuite suite = new TestSuite(AllTests.class.getName());
    // $JUnit-BEGIN$
    suite.addTestSuite(SolrSearchPipelet_AddResultRecords_Test.class);
    suite.addTestSuite(ToSolrQueryConverter_Test.class);
    suite.addTestSuite(SolrIndexPipelet_Index_Test.class);
    suite.addTestSuite(SolrIndexPipelet_Delete_Test.class);
    suite.addTestSuite(SolrAdmin_Embedded_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Facet_Test.class);
    suite.addTestSuite(SolrSearchPipelet_HL_Test.class);
    suite.addTestSuite(SolrSearchPipelet_AutoComplete_Test.class);
    suite.addTestSuite(SolrSearchPipelet_DidYouMean_Test.class);
    suite.addTestSuite(SolrSearchPipelet_MoreLikeThis_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Fields_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Filter_OnBounds_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Filter_OnSets_Test.class);
    suite.addTestSuite(SolrSearchPipelet_Sortby_Test.class);
    suite.addTestSuite(SolrQueryConverter_Test.class);
    // $JUnit-END$
    return suite;
  }

}
